boofun
========

.. automodule:: boofun


   .. rubric:: Functions

   .. autosummary::

      AND
      OR
      constant
      dictator
      from_weights
      majority
      parity
      random
      threshold
      tribes
      weighted_majority

.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   analysis
   api
   benchmarks
   core
   families
   quantum
   testing
   utils
   visualization
